using UnityEngine;
using System;
using System.Collections;
using System.Collections.Generic;

public class InfectiousSyringe : SyringeBehaviour
{
	public override string GetLiquidID() => InfectiousSerum.ID;

	public class InfectiousSerum : Liquid
	{
		public const string ID = "INFECTIOUS SERUM";

		public InfectiousSerum()
		{
			Color = new UnityEngine.Color(0.6835177f, 0.8f, 0.5122642f);
		}

		public override void OnEnterLimb(LimbBehaviour limb)
		{
			limb.IsZombie = true;
        	limb.gameObject.GetOrAddComponent<InfectionBehaviour>();
		}

		public override void OnUpdate(BloodContainer container) { }
		public override void OnEnterContainer(BloodContainer container) { }
		public override void OnExitContainer(BloodContainer container) { }
	}
}

public class InfectionBehaviour : MonoBehaviour
{
    void Update()
    {
        if (!this.gameObject.GetComponent<LimbBehaviour>().IsZombie)
        {
            UnityEngine.Object.Destroy(this);
        }
    }

    public void OnCollisionEnter2D(Collision2D other)
    {
		LimbBehaviour otherLimb = other.gameObject.GetComponent<LimbBehaviour>();
		LimbBehaviour thisLimb = this.gameObject.GetComponent<LimbBehaviour>();
        if (!other.gameObject.GetComponent<InfectionBehaviour>() && otherLimb && thisLimb && thisLimb.Person.IsAlive() && !otherLimb.IsAndroid && thisLimb.Person.Consciousness >= 0.65f)
		{
			other.gameObject.AddComponent<InfectionBehaviour>();
			if (thisLimb.RoughClassification == LimbBehaviour.BodyPart.Head)
			{
				otherLimb.SkinMaterialHandler.ShotDamage(6.9f, other.contacts[0].point);
				StartCoroutine("Bite", otherLimb);
				foreach (LimbBehaviour limb in otherLimb.Person.Limbs)
				{
					limb.Person.Consciousness = 0;
					limb.IsZombie = true;
					StartCoroutine(WaitForInfection(limb));
				}
			}
			else if (thisLimb.RoughClassification == LimbBehaviour.BodyPart.Arms && (otherLimb.CirculationBehaviour.StabWoundCount > 0 || otherLimb.CirculationBehaviour.GunshotWoundCount > 0))
			{
				foreach (LimbBehaviour limb in otherLimb.Person.Limbs)
				{
					GripBehaviour grip = limb.gameObject.GetComponent<GripBehaviour>();
					if (grip)
					{
						grip.DropObject();
					}
					limb.Person.Consciousness = 0;
					limb.IsZombie = true;
					StartCoroutine(WaitForInfection(limb));
				}
			}
        }
    }

    private IEnumerator WaitForInfection(LimbBehaviour limb)
    {
        if (limb.SkinMaterialHandler.RottenProgress >= 1f)
        {
            if (limb.Person.IsAlive())
            {
                limb.Health += limb.InitialHealth;
                limb.CirculationBehaviour.HealBleeding();
                limb.CirculationBehaviour.BleedingRate = 0f;
                limb.CirculationBehaviour.IsPump = limb.CirculationBehaviour.WasInitiallyPumping;
                limb.Numbness = 0f;

                if (limb.RoughClassification == LimbBehaviour.BodyPart.Head)
                {
                    limb.Person.Consciousness = 1f;
                    limb.Person.ShockLevel = 0f;
                    limb.Person.PainLevel = 0f;
                    limb.Person.OxygenLevel = 1f;
                    limb.Person.AdrenalineLevel = 1f;
                }
            }
            yield break;
        }

        yield return new WaitForEndOfFrame();

        StartCoroutine(WaitForInfection(limb));
    }

    private IEnumerator Bite(LimbBehaviour limb)
    {
        if (limb.PhysicalBehaviour.Properties.StabSound.Length != 0)
            limb.gameObject.AddComponent<AudioSource>().PlayOneShot(limb.PhysicalBehaviour.Properties.StabSound.PickRandom<AudioClip>(), 0.6f);

        FixedJoint2D joint = this.gameObject.AddComponent<FixedJoint2D>();
        joint.breakForce = 75f;
        joint.breakTorque = 75f;
        joint.connectedBody = limb.PhysicalBehaviour.rigidbody;
        joint.enabled = true;

        yield return new WaitForSeconds(1f);

        joint.enabled = false;
    }
}