using UnityEngine;
using System;
using System.Collections;
using System.Collections.Generic;

public class LifeAbsorptionSyringe : SyringeBehaviour
{
    public override string GetLiquidID() => LifeAbsorptionSerum.ID;

	public class LifeAbsorptionSerum : Liquid
	{
		public const string ID = "LIFE ABSORPTION SERUM";

		public LifeAbsorptionSerum()
		{
			Color = new UnityEngine.Color(0.8f, 1f, 0.9f);
		}

		public override void OnEnterLimb(LimbBehaviour limb)
		{
			limb.gameObject.GetOrAddComponent<LifeAbsorptionBehaviour>();
		}

		public override void OnUpdate(BloodContainer container) { }
		public override void OnEnterContainer(BloodContainer container) { }
		public override void OnExitContainer(BloodContainer container) { }
	}
}

public class LifeAbsorptionBehaviour : MonoBehaviour
{
    bool healing;

    public void OnCollisionEnter2D(Collision2D other)
    {
		LimbBehaviour otherLimb = other.gameObject.GetComponent<LimbBehaviour>();
		LimbBehaviour thisLimb = this.gameObject.GetComponent<LimbBehaviour>();
        if (thisLimb.Person.IsAlive() && thisLimb.RoughClassification == LimbBehaviour.BodyPart.Arms && otherLimb != null)
		{
			foreach (LimbBehaviour limb in thisLimb.Person.Limbs)
			{
				if (otherLimb.Person.IsAlive())
				{
					healing = true;
					limb.HealBone();
					limb.RegenerationSpeed += 3f;
					limb.CirculationBehaviour.HealBleeding();
					limb.CirculationBehaviour.BloodFlow = 5f;
					limb.CirculationBehaviour.AddLiquid(thisLimb.GetOriginalBloodType(), 5f);
					limb.Numbness = 0f;
					limb.Person.Consciousness = 1f;
					limb.BruiseCount = 0;
					limb.CirculationBehaviour.GunshotWoundCount = 0;
					limb.CirculationBehaviour.StabWoundCount = 0;
					limb.Health = Math.Max(limb.Health, 1);
					limb.LungsPunctured = false;
					StartCoroutine(this.HealRottenFlesh(limb));
					StartCoroutine(this.HealAcidFlesh(limb));
					StartCoroutine(this.HealBurn(limb));
					StartCoroutine(this.HealBulletHoles(limb));
					StartCoroutine(this.HealWounds(limb));
				}
			}

			foreach (LimbBehaviour limb in otherLimb.Person.Limbs)
			{
				limb.RegenerationSpeed -= 1;
				StartCoroutine(this.Burn(limb, 0.79f));
			}
		}
    }

    private IEnumerator Burn(LimbBehaviour Limb, float Amount)
    {
        FixedJoint2D joint = this.gameObject.AddComponent<FixedJoint2D>();
        joint.breakForce = 100f;
        joint.breakTorque = 100f;
        joint.connectedBody = Limb.PhysicalBehaviour.rigidbody;
        joint.enabled = true;
        while (Limb.PhysicalBehaviour.BurnProgress < Amount)
        {
            Limb.PhysicalBehaviour.BurnProgress += 0.005f;
            yield return new WaitForEndOfFrame();
        }
        joint.enabled = false;
    }

    private IEnumerator HealBurn(LimbBehaviour limb)
    {
        while (limb.PhysicalBehaviour.BurnProgress > 0.1f)
        {
            limb.PhysicalBehaviour.BurnProgress -= Time.deltaTime * 0.16f;
            yield return new WaitForEndOfFrame();
        }
        limb.PhysicalBehaviour.BurnProgress = 0f;
        yield break;
    }

    private IEnumerator HealAcidFlesh(LimbBehaviour limb)
    {
        while (limb.SkinMaterialHandler.AcidProgress > 0.1f)
        {
            limb.SkinMaterialHandler.AcidProgress -= Time.deltaTime * 0.8f;
            yield return new WaitForEndOfFrame();
        }
        limb.SkinMaterialHandler.AcidProgress = 0f;
        yield break;
    }

    private IEnumerator HealRottenFlesh(LimbBehaviour limb)
    {
        while (limb.SkinMaterialHandler.RottenProgress > 0.1f)
        {
            limb.SkinMaterialHandler.RottenProgress -= Time.deltaTime * 0.8f;
            yield return new WaitForEndOfFrame();
        }
        limb.SkinMaterialHandler.RottenProgress = 0f;
        yield break;
    }

    private IEnumerator HealBulletHoles(LimbBehaviour limb)
    {
        while (healing)
        {
            for (int i = 0; i < limb.SkinMaterialHandler.bulletHolePoints.Length; i++)
            {
                limb.SkinMaterialHandler.bulletHolePoints[i].z = Mathf.Max(limb.SkinMaterialHandler.bulletHolePoints[i].z, 0.05f);
                Vector4[] bulletHolePoints = limb.SkinMaterialHandler.bulletHolePoints;
                int num = i;
                bulletHolePoints[num].z = bulletHolePoints[num].z + Time.deltaTime * 0.5f;
                if (!healing)
                {
                    break;
                }
            }
            limb.SkinMaterialHandler.Sync();
            yield return new WaitForEndOfFrame();
        }
        yield break;
    }

    private IEnumerator HealWounds(LimbBehaviour limb)
    {
        while (healing)
        {
            for (int i = 0; i < limb.SkinMaterialHandler.damagePoints.Length; i++)
            {
                Vector4[] damagePoints = limb.SkinMaterialHandler.damagePoints;
                int num = i;
                damagePoints[num].z = damagePoints[num].z + Time.deltaTime * 0.5f;
                if (!healing)
                {
                    break;
                }
            }
            limb.SkinMaterialHandler.Sync();
            yield return new WaitForEndOfFrame();
        }
        yield break;
    }

    public void OnCollisionExit2D(Collision2D other)
    {
		LimbBehaviour otherLimb = other.gameObject.GetComponent<LimbBehaviour>();
		LimbBehaviour thisLimb = this.gameObject.GetComponent<LimbBehaviour>();
        if (thisLimb.RoughClassification == LimbBehaviour.BodyPart.Arms && otherLimb != null)
        {
			foreach (LimbBehaviour limb in thisLimb.Person.Limbs)
			{
				foreach (LimbBehaviour limb2 in otherLimb.Person.Limbs)
				{
					StartCoroutine(StopHealing(limb, limb2));
				}
			}
		}
    }

    private IEnumerator StopHealing(LimbBehaviour limb, LimbBehaviour otherLimb)
    {
        yield return new WaitForSeconds(2f);
        healing = false;
        limb.RegenerationSpeed = 0f;
        otherLimb.RegenerationSpeed = 0f;
    }
}