using UnityEngine;
using System;
using System.Collections;
using System.Collections.Generic;

public class SyringeGunBehaviour : MonoBehaviour
{
    private SyringeBehaviour CurrentSyringe;
    private Material OldMaterial;

    void Update()
    {
		PhysicalBehaviour physBehaviour = this.gameObject.GetComponent<PhysicalBehaviour>();
        foreach (PhysicalBehaviour impaler in physBehaviour.beingStabbedBy)
        {
            if (impaler.gameObject.GetComponent<SyringeBehaviour>())
                GetSyringe(impaler);
        }

        if (CurrentSyringe != null && !physBehaviour.beingStabbedBy.Contains(CurrentSyringe.gameObject.GetComponent<PhysicalBehaviour>()))
			RemoveSyringe();
    }

    private void GetSyringe(PhysicalBehaviour Syringe)
    {
		if (CurrentSyringe != null) return;

		SpriteRenderer rend = Syringe.gameObject.GetComponent<SpriteRenderer>();
		OldMaterial = rend.material;
		rend.material = ModAPI.FindMaterial("VeryBright");
		CurrentSyringe = Syringe.gameObject.GetComponent<SyringeBehaviour>();
    }

    private void RemoveSyringe()
    {
		if (CurrentSyringe == null) return;

        CurrentSyringe.gameObject.GetComponent<SpriteRenderer>().material = OldMaterial;
        CurrentSyringe = null;
    }

    public void AddPoison(LimbBehaviour limb)
    {
		if (CurrentSyringe == null)
		{
			ModAPI.Notify("Must add a syringe to the gun to have an effect");
			return;
		}

		BloodContainer container = limb.CirculationBehaviour.GetComponent<BloodContainer>();
		BloodContainer container2 = CurrentSyringe.GetComponent<BloodContainer>();
		string liquidID = CurrentSyringe.GetLiquidID();
		if (container2 != null)
			if (CurrentSyringe.Finite) container2.TransferTo(0.1f, container, false);
			else container2.CopyTo(0.1f, container, false);
		else if (liquidID != null)
		{
			Liquid liquid = Liquid.GetLiquid(liquidID);

			if (liquid != null) container.AddLiquid(liquid, 0.1f);
			else ModAPI.Notify("Syringe has invalid liquid ID");
		}
		else ModAPI.Notify("Syringe is invalid");
    }
}