using UnityEngine;
using System;
using System.Collections;
using System.Collections.Generic;

namespace Mod
{
    public class Script
    {
        public static void Main()
        {
			ModAPI.RegisterLiquid(InfectiousSyringe.InfectiousSerum.ID, new InfectiousSyringe.InfectiousSerum());
			ModAPI.Register(
				new Modification()
				{
					OriginalItem = ModAPI.FindSpawnable("Zombie Syringe"),
					NameOverride = "Infectious Syringe",
					NameToOrderByOverride = "WS6",
					DescriptionOverride = "Gives the user a zombie-like virus that spreads from person to person by bite. Scratches will only infect if previously wounded.",
					CategoryOverride = ModAPI.FindCategory("Biohazard"),
					ThumbnailOverride = ModAPI.LoadSprite("images/items/infect_syringe.png"),
					AfterSpawn = (Instance) =>
					{
						Instance.AddComponent<InfectiousSyringe>();
					}
				}
			);

			ModAPI.RegisterLiquid(LifeAbsorptionSyringe.LifeAbsorptionSerum.ID, new LifeAbsorptionSyringe.LifeAbsorptionSerum());
			ModAPI.Register(
				new Modification()
				{
					OriginalItem = ModAPI.FindSpawnable("Knockout Syringe"),
					NameOverride = "Life Absorption Syringe",
					NameToOrderByOverride = "WS5",
					DescriptionOverride = "Gives the user the ability to heal themselves, at the cost of other lives.",
					CategoryOverride = ModAPI.FindCategory("Biohazard"),
					ThumbnailOverride = ModAPI.LoadSprite("images/items/lifeabsorb_syringe.png"),
					AfterSpawn = (Instance) =>
					{
						UnityEngine.Object.Destroy(Instance.GetComponent<KnockoutSyringe>());
                		Instance.AddComponent<LifeAbsorptionSyringe>();
					}
				}
			);

			ModAPI.RegisterLiquid(TrapSyringe.TrapSerum.ID, new TrapSyringe.TrapSerum());
			ModAPI.Register(
				new Modification()
				{
					OriginalItem = ModAPI.FindSpawnable("Bone Eating Syringe"),
					NameOverride = "Trap Syringe",
					NameToOrderByOverride = "WS1",
					DescriptionOverride = "Rigs the person injected to explode on death.",
					CategoryOverride = ModAPI.FindCategory("Biohazard"),
					ThumbnailOverride = ModAPI.LoadSprite("images/items/trap_syringe.png"),
					AfterSpawn = (Instance) =>
					{
						UnityEngine.Object.Destroy(Instance.GetComponent<BoneEatingPoisonSyringe>());
                		Instance.AddComponent<TrapSyringe>();
					}
				}
			);

			ModAPI.Register(
				new Modification()
				{
					OriginalItem = ModAPI.FindSpawnable("Pistol"),
					NameOverride = "Syringe Gun",
					NameToOrderByOverride = "WS99",
					DescriptionOverride = "Insert a syringe into any part of the gun and it's bullets will carry on it's effects as long as the syringe is in the gun.",
					ThumbnailOverride = ModAPI.LoadSprite("images/items/syringe_gun.png"),
					CategoryOverride = ModAPI.FindCategory("Biohazard"),
					AfterSpawn = (Instance) =>
					{
						Instance.GetComponent<PhysicalBehaviour>().Properties.Softness = 0.4f;
						Instance.GetComponent<SpriteRenderer>().sortingOrder += 10;

						Cartridge customCartridge = ModAPI.FindCartridge("9mm"); 
						customCartridge.name = "Syringe Bullet"; 
						customCartridge.Damage = 0.69f; 
						customCartridge.ImpactForce *= 1.3f;
						customCartridge.StartSpeed = 45;
						Instance.GetComponent<FirearmBehaviour>().Cartridge = customCartridge;

						Instance.AddComponent<SyringeGunBehaviour>();
					}
				}
			);
            ModAPI.OnGunShot += (sender, gun) =>
            {
                if (gun.Cartridge.name == "Syringe Bullet")
                {
                    SyringeGunBehaviour SyringeGun = gun.gameObject.GetComponent<SyringeGunBehaviour>();
                    gun.BallisticsEmitter.BulletEntryCallback += (args) =>
                    {
						LimbBehaviour limb = args.HitObject.gameObject.GetComponent<LimbBehaviour>();
                        if (limb) SyringeGun.AddPoison(limb);
                    };
                }
            };

			ModAPI.RegisterLiquid(SuperpowerSyringe.SuperpowerSerum.ID, new SuperpowerSyringe.SuperpowerSerum());
			ModAPI.Register(
				new Modification()
				{
					OriginalItem = ModAPI.FindSpawnable("Pink Syringe"),
					NameOverride = "Super Strength Syringe",
					NameToOrderByOverride = "WS4",
					DescriptionOverride = "Gives the user super strength. Anyone injected with this will be strong and resistant.",
					ThumbnailOverride = ModAPI.LoadSprite("images/items/superpower_syringe.png"),
					CategoryOverride = ModAPI.FindCategory("Biohazard"),
					AfterSpawn = (Instance) =>
					{
						Instance.GetComponent<SpriteRenderer>().material = ModAPI.FindMaterial("VeryBright");
						UnityEngine.Object.Destroy(Instance.GetComponent<PinkSyringe>());
						Instance.AddComponent<SuperpowerSyringe>();
					}
				}
			);
		}
	}
}